==> Couchbase-Java-Client-3.2.0.zip: com/couchbase/client/java/search/queries/RegexpQuery.java <==
/*
 * Copyright (c) 2016 Couchbase, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.couchbase.client.java.search.queries;

import com.couchbase.client.java.json.JsonObject;
import com.couchbase.client.java.search.SearchQuery;

/**
 * A FTS query that allows for simple matching of regular expressions.
 *
 * @author Simon Baslé
 * @author Michael Nitschinger
 * @since 2.3.0
 */
public class RegexpQuery extends SearchQuery {

    private final String regexp;
    private String field;

    public RegexpQuery(String regexp) {
        super();
        this.regexp = regexp;
    }

    public RegexpQuery field(String field) {
        this.field = field;
        return this;
    }

    @Override
    public RegexpQuery boost(double boost) {
        super.boost(boost);
        return this;
    }

    @Override
    protected void injectParams(JsonObject input) {
        input.put("regexp", regexp);
        if (field != null) {
            input.put("field", field);
        }
    }
}

==> Couchbase-Java-Client-3.9.2.zip: com/couchbase/client/java/search/queries/RegexpQuery.java <==
/*
 * Copyright (c) 2016 Couchbase, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.couchbase.client.java.search.queries;

import com.couchbase.client.core.api.search.CoreSearchQuery;
import com.couchbase.client.core.api.search.queries.CoreRegexpQuery;
import com.couchbase.client.java.search.SearchQuery;

/**
 * A FTS query that allows for simple matching of regular expressions.
 *
 * @author Simon Baslé
 * @author Michael Nitschinger
 * @since 2.3.0
 */
public class RegexpQuery extends SearchQuery {

    private final String regexp;
    private String field;

    public RegexpQuery(String regexp) {
        super();
        this.regexp = regexp;
    }

    public RegexpQuery field(String field) {
        this.field = field;
        return this;
    }

    @Override
    public RegexpQuery boost(double boost) {
        super.boost(boost);
        return this;
    }

    @Override
    public CoreSearchQuery toCore() {
        return new CoreRegexpQuery(regexp, field, boost);
    }
}
